BleDevice class

BLE设备信息

Constructors

BleDevice({required String deviceId, required String deviceName, required String mac, required int rssi})
BleDevice.fromMap(Map map)
factory

Properties

deviceId String
final
deviceName String
final
hashCode int
The hash code for this object.
no setterinherited
mac String
final
rssi int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited