TranslationListener class abstract

翻译监听器

Constructors

TranslationListener()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onConsumeTokens(String tokenType, int tokens) → void
onError(int errorCode, String error) → void
onRecognitionResult(String id, String text, bool isFinal, bool isLeft) → void
onTranslation(String id, String sourceText, String translatedText, bool isLeft) → void
onTtsFile(String id, String filePath, bool isLeft) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited