BleAgentFlutter class
BleAgent Flutter SDK
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addDeviceListener(
BleDeviceListener listener) → void - 添加设备监听器
-
addTranslationListener(
TranslationListener listener) → void - 添加翻译监听器
-
connectDevice(
String deviceId) → Future< void> - 连接设备
-
deleteAllTtsCacheFiles(
) → Future< void> - 删除所有TTS缓存文件
-
disconnectDevice(
) → Future< void> - 断开设备连接
-
fetchLanguages(
) → Future< List< Language> > - 获取支持的语言列表
-
initialize(
{required String userId, required String organizationId, required String secret, required String appPackageName, required String country}) → Future< String> - 初始化SDK
-
isDeviceConnected(
) → Future< bool> - 检查设备是否已连接
-
isInitialized(
) → Future< bool> - 检查SDK是否已初始化
-
isTtsCacheEnabled(
) → Future< bool> - 检查TTS缓存是否启用
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
release(
) → Future< void> - 释放资源
-
removeDeviceListener(
BleDeviceListener listener) → void - 移除设备监听器
-
removeTranslationListener(
TranslationListener listener) → void - 移除翻译监听器
-
scanDevices(
) → Future< void> - 扫描设备
-
setTtsCacheEnabled(
bool enabled) → Future< void> - 设置TTS缓存启用状态
-
startCallRecording(
) → Future< void> - 开始通话录音
-
startTranslation(
{required WorkMode workMode, required String sourceLang, required String targetLang, required StepMode stepMode}) → Future< void> - 开始翻译
-
stopRecordingAndTranslation(
) → Future< void> - 停止录音或翻译
-
stopScan(
) → Future< void> - 停止扫描设备
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited