BleDeviceListener class abstract
BLE设备监听器
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onAudioModeUpdated(
int errorCode, String errorMessage) → void -
onAudioStreamData(
List< int> audioData) → void -
onConnected(
BleDevice device) → void -
onDeviceFound(
BleDevice device) → void -
onDisconnected(
BleDevice device) → void -
onError(
String error) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited